# 云服务

## 目前提供的功能

* 消息服务

    `发消息 liamcloud.robot.chat('哈哈哈哈')`


cp -f .pypirc ~/

ls -a
cd /tf/notebooks/liamcloud

python setup.py register

打包： python setup.py sdist
上传：python setup.py sdist upload

类的调用
https://blog.csdn.net/qq_36134318/article/details/80640667
